==> toolbox-17.0.11-sources.jar: eu/hansolo/toolbox/properties/ReadOnlyObjectProperty.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright 2016-2021 Gerrit Grunwald.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package eu.hansolo.toolbox.properties;


public class ReadOnlyObjectProperty<T> extends ReadOnlyProperty<T> {
    protected ObjectProperty<T> propertyToUpdate;
    protected boolean           bidirectional;


    // ******************** Constructors **************************************
    public ReadOnlyObjectProperty() {
        super(null, null, null);
    }
    public ReadOnlyObjectProperty(final T value) {
        super(null, null, value);
    }
    public ReadOnlyObjectProperty(final Object bean, final String name, final T value) {
        super(bean, name, value);
        this.propertyToUpdate = null;
        this.bidirectional    = false;
    }


    // ******************** Methods *******************************************
    public T get() { return value; }

    protected void setPropertyToUpdate(final ObjectProperty<T> property) {
        this.propertyToUpdate = property;
        this.bidirectional    = false;
    }
    protected void unsetPropertyToUpdate() {
        this.propertyToUpdate = null;
        this.bidirectional    = false;
    }
}

==> toolbox-17.0.19-sources.jar: eu/hansolo/toolbox/properties/ReadOnlyObjectProperty.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright 2016-2021 Gerrit Grunwald.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package eu.hansolo.toolbox.properties;


public class ReadOnlyObjectProperty<T> extends ReadOnlyProperty<T> {
    protected ObjectProperty<T> propertyToUpdate;
    protected boolean           bidirectional;


    // ******************** Constructors **************************************
    public ReadOnlyObjectProperty() {
        super(null, null, null);
    }
    public ReadOnlyObjectProperty(final T value) {
        super(null, null, value);
    }
    public ReadOnlyObjectProperty(final Object bean, final String name, final T value) {
        super(bean, name, value);
        this.propertyToUpdate = null;
        this.bidirectional    = false;
    }


    // ******************** Methods *******************************************
    public T get() { return value; }

    protected void setPropertyToUpdate(final ObjectProperty<T> property) {
        this.propertyToUpdate = property;
        this.bidirectional    = false;
    }
    @Override protected void unsetPropertyToUpdate() {
        this.propertyToUpdate = null;
        this.bidirectional    = false;
    }
}
